@@ -15,17 +15,21 @@ Distributed under the Boost Software License, Version 1.0.
 #include <boost/hana/config.hpp>
 #include <boost/hana/core/default.hpp>
 #include <boost/hana/core/tag_of.hpp>
+#include <boost/hana/detail/integral_constant.hpp>
 #include <boost/hana/div.hpp>
 #include <boost/hana/mod.hpp>
 
 
 BOOST_HANA_NAMESPACE_BEGIN
     template <typename R>
-    struct EuclideanRing {
-        using Tag = typename tag_of<R>::type;
-        static constexpr bool value = !is_default<mod_impl<Tag, Tag>>::value &&
-                                      !is_default<div_impl<Tag, Tag>>::value;
-    };
+    struct EuclideanRing
+        : hana::integral_constant<bool,
+            !is_default<mod_impl<typename tag_of<R>::type,
+                                 typename tag_of<R>::type>>::value &&
+            !is_default<div_impl<typename tag_of<R>::type,
+                                 typename tag_of<R>::type>>::value
+        >
+    { };
 BOOST_HANA_NAMESPACE_END
 
 #endif // !BOOST_HANA_CONCEPT_EUCLIDEAN_RING_HPP
