@@ -16,14 +16,16 @@ Distributed under the Boost Software License, Version 1.0.
 #include <boost/hana/config.hpp>
 #include <boost/hana/core/default.hpp>
 #include <boost/hana/core/tag_of.hpp>
+#include <boost/hana/detail/integral_constant.hpp>
 
 
 BOOST_HANA_NAMESPACE_BEGIN
     template <typename S>
-    struct Struct {
-        using Tag = typename tag_of<S>::type;
-        static constexpr bool value = !is_default<accessors_impl<Tag>>::value;
-    };
+    struct Struct
+        : hana::integral_constant<bool,
+            !is_default<accessors_impl<typename tag_of<S>::type>>::value
+        >
+    { };
 BOOST_HANA_NAMESPACE_END
 
 #endif // !BOOST_HANA_CONCEPT_STRUCT_HPP
