@@ -1,16 +1,16 @@
 // Boost.Geometry (aka GGL, Generic Geometry Library)
 // Unit Test
 
-// Copyright (c) 2010 Alfredo Correa 
+// Copyright (c) 2010 Alfredo Correa
 // Copyright (c) 2010-2012 Barend Gehrels, Amsterdam, the Netherlands.
 
 // Use, modification and distribution is subject to the Boost Software License,
 // Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt)
 
+#include <boost/config.hpp>
 #include <geometry_test_common.hpp>
 
-
 #include<boost/geometry/geometry.hpp>
 #include<boost/geometry/geometries/adapted/boost_array.hpp>
 #include<boost/geometry/geometries/adapted/c_array.hpp>
@@ -21,6 +21,10 @@ BOOST_GEOMETRY_REGISTER_C_ARRAY_CS(cs::cartesian)
 BOOST_GEOMETRY_REGISTER_BOOST_ARRAY_CS(cs::cartesian)
 BOOST_GEOMETRY_REGISTER_BOOST_TUPLE_CS(cs::cartesian)
 
+#ifndef BOOST_NO_CXX11_HDR_ARRAY 
+#include<boost/geometry/geometries/adapted/std_array.hpp>
+BOOST_GEOMETRY_REGISTER_STD_ARRAY_CS(cs::cartesian)
+#endif //BOOST_NO_CXX11_HDR_ARRAY 
 
 int test_main(int, char* [])
 {
@@ -31,6 +35,12 @@ int test_main(int, char* [])
     std::clog << bg::distance(p1, p2) << std::endl;
     std::clog << bg::distance(p2, p3) << std::endl;
     std::clog << bg::distance(p3, p4) << std::endl;
+
+#ifndef BOOST_NO_CXX11_HDR_ARRAY 
+    std::array<double, 3> p5{13,14,15};
+    std::clog << bg::distance(p4, p5) << std::endl;
+#endif //BOOST_NO_CXX11_HDR_ARRAY 
+
     return 0;
 }
 
