@@ -9,7 +9,13 @@ namespace hana = boost::hana;
 
 
 constexpr auto str = hana::string_c<'h', 'i'>;
-constexpr char const* s = hana::to<char const*>(str);
-static_assert(s[0] == 'h' && s[1] == 'i' && s[2] == '\0', "");
+
+// using c_str()
+constexpr char const* s1 = str.c_str();
+static_assert(s1[0] == 'h' && s1[1] == 'i' && s1[2] == '\0', "");
+
+// using hana::to
+constexpr char const* s2 = hana::to<char const*>(str);
+static_assert(s2[0] == 'h' && s2[1] == 'i' && s2[2] == '\0', "");
 
 int main() { }
